"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getConfig = void 0;
const mini_css_extract_plugin_1 = __importStar(require("mini-css-extract-plugin"));
const optimize_css_assets_webpack_plugin_1 = __importDefault(require("optimize-css-assets-webpack-plugin"));
const client_plugin_1 = __importDefault(require("vue-server-renderer/client-plugin"));
const terser_webpack_plugin_1 = __importDefault(require("terser-webpack-plugin"));
const webpack = __importStar(require("webpack"));
const getConfig = function getConfig(base, option) {
    const isDev = option.mode === 'development';
    // 设置 entry，开发模式支持 hmr
    let entry = {};
    if (typeof option.entry === 'string') {
        entry = {
            app: isDev ? [`webpack-hot-middleware/client?path=${option.hmrPath}`, option.entry] : option.entry,
        };
    }
    else {
        entry = { ...option.entry };
    }
    const config = {
        ...base,
        entry,
        mode: option.mode,
        devtool: isDev ? '#source-map' : false,
        output: {
            filename: isDev ? '[name].js' : '[name]/app.[contenthash:4].js',
            path: option.dist,
            publicPath: option.publicPath,
            libraryTarget: 'umd',
            library: 'rieApp',
        },
        externals: {
            vue: {
                commonjs2: ['rieVue2Runtime', 'Vue'],
                commonjs: ['rieVue2Runtime', 'Vue'],
                root: ['rieVue2Runtime', 'Vue'],
            },
        },
    };
    config.module.rules.push({
        test: /\.tsx?$/,
        loader: 'ts-loader',
        options: {
            appendTsSuffixTo: [/\.vue$/],
            transpileOnly: true,
            compilerOptions: {
                target: 'es5',
                esModuleInterop: true,
            },
        },
    }, {
        test: /\.jsx?$/,
        use: [
            {
                loader: 'babel-loader',
                options: {
                    cwd: __dirname,
                    sourceType: 'unambiguous',
                    presets: [
                        [
                            '@babel/preset-env',
                            {
                                targets: {
                                    browsers: ['ios >= 9', 'Android >= 6.0'],
                                },
                            },
                        ],
                    ],
                    plugins: [
                        ['@babel/plugin-transform-runtime'],
                        ['@babel/plugin-proposal-decorators', { legacy: true }],
                        ['@babel/plugin-proposal-class-properties'],
                    ],
                },
            },
            '@riejs/packer-utils/lib/loaders/client-fetch-loader',
        ],
    }, {
        test: /\.css$/,
        use: [isDev ? 'vue-style-loader' : mini_css_extract_plugin_1.loader, { loader: 'css-loader', options: { esModule: false } }],
    }, {
        test: /\.less$/,
        use: [
            isDev ? 'vue-style-loader' : mini_css_extract_plugin_1.loader,
            { loader: 'css-loader', options: { esModule: false } },
            'less-loader',
        ],
    });
    config.plugins.push(new webpack.DefinePlugin({
        'process.env.NODE_ENV': JSON.stringify(process.env.NODE_ENV || option.mode),
        'process.env.VUE_ENV': JSON.stringify('client'),
    }), new client_plugin_1.default({
        filename: 'rie.vue2.app.manifest.json',
    }));
    if (isDev) {
        config.plugins.push(new webpack.HotModuleReplacementPlugin(), new webpack.NoEmitOnErrorsPlugin(), new webpack.ProgressPlugin(option.onProgress));
    }
    else {
        config.plugins.push(new mini_css_extract_plugin_1.default({ filename: '[name]/app.[contenthash:4].css' }), new optimize_css_assets_webpack_plugin_1.default());
        config.optimization = {
            minimizer: [
                new terser_webpack_plugin_1.default({
                    terserOptions: {
                        compress: {
                            drop_console: true,
                            collapse_vars: true,
                            reduce_vars: true,
                        },
                        output: {
                            beautify: false,
                            comments: false,
                        },
                        mangle: true,
                    },
                    extractComments: false,
                }),
            ],
        };
    }
    return config;
};
exports.getConfig = getConfig;
