"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Packer = void 0;
const fs_1 = require("fs");
const path_1 = require("path");
const webpack_1 = __importDefault(require("webpack"));
const webpack_base_1 = require("../conf/webpack.base");
const webpack_client_1 = require("../conf/webpack.client");
const webpack_server_1 = require("../conf/webpack.server");
const clone_deep_1 = __importDefault(require("clone-deep"));
const html_webpack_plugin_1 = __importDefault(require("html-webpack-plugin"));
const webpack_merge_1 = require("webpack-merge");
const file_1 = require("../utlis/file");
const template_1 = require("../utlis/template");
const defaultTemplate = fs_1.readFileSync(path_1.resolve(__dirname, '../../template.html'), 'utf-8');
/**
 * 正式环境构建
 */
class Packer {
    constructor(option) {
        var _a, _b, _c, _d;
        this.clientConfig = clone_deep_1.default(webpack_base_1.config);
        this.serverConfig = clone_deep_1.default(webpack_base_1.config);
        this.patterns = [];
        this.option = option;
        const entry = {};
        const clientPlugins = [];
        const serverPlugins = [];
        const appManifest = 'rie.vue2.app.manifest.json';
        this.patterns.push({
            from: path_1.resolve(__dirname, '../single-vue/server'),
            to: this.serverDist,
        }, {
            from: path_1.resolve(__dirname, '../single-vue/client'),
            to: this.clientDist,
        });
        option.pages.forEach((page) => {
            const chunkId = page.route.replace(/^\//, '');
            entry[chunkId] = `${page.dir}/index.vue`;
            this.patterns.push({
                from: path_1.resolve(this.clientDist, `./${appManifest}`),
                to: path_1.resolve(this.clientDist, `.${page.route}`, `./${appManifest}`),
            });
            const template = page.template || defaultTemplate;
            const isDev = option.mode === 'development' || option.mode === 'test';
            clientPlugins.push(new html_webpack_plugin_1.default({
                scriptLoading: 'defer',
                templateContent: template_1.getClientTemplate(template, {
                    publicPath: option.runtimePublicPath || option.publicPath,
                    isDev,
                }),
                chunks: [chunkId],
                filename: path_1.resolve(this.clientDist, `.${page.route}`, './index.html'),
                minify: false,
            }));
            serverPlugins.push(new html_webpack_plugin_1.default({
                inject: false,
                templateContent: template_1.getServerTemplate(template, { isDev }),
                chunks: [chunkId],
                filename: path_1.resolve(this.serverDist, `.${page.route}`, './template.html'),
                minify: false,
            }));
        });
        this.clientConfig = webpack_client_1.getConfig(this.clientConfig, {
            mode: 'production',
            dist: this.clientDist,
            entry,
            publicPath: option.publicPath,
        });
        this.clientConfig.plugins.push(...clientPlugins);
        this.clientConfig = webpack_merge_1.merge(this.clientConfig, (_b = (_a = option.packerOption) === null || _a === void 0 ? void 0 : _a.client) !== null && _b !== void 0 ? _b : {});
        this.serverConfig = webpack_server_1.getConfig(this.serverConfig, {
            mode: 'production',
            dist: this.serverDist,
            entry,
            publicPath: option.publicPath,
            onProgress() { },
        });
        this.serverConfig.plugins.push(...serverPlugins);
        this.serverConfig = webpack_merge_1.merge(this.serverConfig, (_d = (_c = option.packerOption) === null || _c === void 0 ? void 0 : _c.server) !== null && _d !== void 0 ? _d : {});
    }
    get clientDist() {
        return path_1.resolve(this.option.dist, 'client');
    }
    get serverDist() {
        return path_1.resolve(this.option.dist, 'server');
    }
    /**
     * vue 2.0 文件打包
     */
    async build() {
        await this.compile([this.serverConfig, this.clientConfig]).catch((error) => {
            console.log(error);
        });
        await file_1.copy(this.patterns);
    }
    compile(options) {
        return new Promise((resolve, reject) => {
            // @ts-ignore
            webpack_1.default(options, (err, stats) => {
                if (err) {
                    return reject(err);
                }
                const info = stats.toJson();
                if (stats.hasErrors()) {
                    return reject(info.errors[0]);
                }
                return resolve(true);
            });
        });
    }
}
exports.Packer = Packer;
