"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getClientTemplate = exports.getServerTemplate = void 0;
const fs_1 = require("fs");
const path_1 = require("path");
const initScript = isDev => `
  <script>
    document.addEventListener('DOMContentLoaded', function() {
      var app = window.rieApp.default || window.rieApp;
      window.rieVue2Runtime.Vue.config.devtools = ${isDev || false};
      window.rieVue2Runtime.init(app);
    });
  </script>`;
let manifest = {
    initial: [],
};
try {
    const content = fs_1.readFileSync(path_1.resolve(__dirname, '../single-vue/server/rie.vue2.runtime.manifest.json'), 'utf-8');
    manifest = JSON.parse(content);
}
catch (exception) { }
const getServerTemplate = function getServerTemplate(template, { isDev }) {
    const headScripts = [
        '{{{ meta.inject().meta ? meta.inject().meta.text() : \'\' }}}',
        '{{{ meta.inject().title ? meta.inject().title.text() : \'\' }}}',
        '{{{ meta.inject().style ? meta.inject().style.text() : \'\' }}}',
        '{{{ meta.inject().link ? meta.inject().link.text() : \'\' }}}',
        '{{{ meta.inject().script ? meta.inject().script.text() : \'\' }}}',
        '</head>',
    ].join('\n');
    const bodyScripts = [
        '<!--vue-ssr-outlet-->',
        '{{{renderState({contextKey: "asyncData", windowKey: "__INITIAL_ASYNCDATA__"})}}}',
        initScript(isDev),
    ].join('\n');
    return template.replace('</head>', headScripts).replace('<!--vue-ssr-outlet-->', bodyScripts);
};
exports.getServerTemplate = getServerTemplate;
const getClientTemplate = function getServerTemplate(template, { publicPath, isDev }) {
    const headScripts = [];
    manifest.initial.forEach((asset) => {
        const script = asset.match(/\.js$/)
            ? `<script defer src="${path_1.resolve(publicPath, asset)}"></script>`
            : `<link rel="stylesheet" herf="${path_1.resolve(publicPath, asset)}" >`;
        headScripts.push(script);
    });
    headScripts.push('</head>');
    const bodyScripts = ['<div id="app"></div>', initScript(isDev)].join('\n');
    return template.replace('</head>', headScripts.join('\n')).replace('<!--vue-ssr-outlet-->', bodyScripts);
};
exports.getClientTemplate = getClientTemplate;
